'''
Created on 2020-09-10

@author: wf
'''

class Labels(object):
    '''
    NLTK labels
    '''
    default=['GPE','GSP','PERSON','ORGANIZATION']
    geo=['GPE','GSP']